"use client";

import React from "react";

import { motion } from "framer-motion";

import { Link } from "@/i18n/routing";
import { cn } from "@/lib/utils";

type ProgressbarProps = {
	progress: number;
	leftText?: string;
	rightText?: string;
	progressColor: string;
	rightTextColor?: string;
	className?: string;
	dir?: "ltr" | "rtl";
	height?: string;
	isLink?: boolean;
};

const Progressbar: React.FC<ProgressbarProps> = ({
	progress,
	leftText,
	rightText,
	progressColor,
	rightTextColor,
	height,
	className = "text-custom-fifth",
	dir = "ltr",
	isLink = false,
}) => {
	return (
		<div dir={dir} className={`flex flex-col gap-2 ${className}`}>
			<div className="flex items-center justify-between">
				{leftText && <p className="text-sm">{leftText}</p>}
				{rightText && (
					<p style={{ color: rightTextColor }} className="text-sm">
						{isLink ? (
							<Link href={"/simulation-program" as any}>{rightText}</Link>
						) : (
							rightText
						)}
					</p>
				)}
			</div>
			<div
				className={cn(
					"relative h-2 overflow-hidden rounded-full bg-[#E9ECEF]",
					height
				)}
			>
				<motion.div
					className={cn("h-full")}
					style={{ backgroundColor: progressColor }}
					initial={{ width: "0%" }}
					animate={{ width: `${progress}%` }}
					transition={{ duration: 0.6, ease: "easeInOut" }}
					whileHover={{ scale: 1.05 }}
				></motion.div>
			</div>
		</div>
	);
};

export default Progressbar;
